pub enum TlsLevel {
MozillaModern,
MozillaModernV5,
MozillaIntermediate,
MozillaIntermediateV5,
}Expand description
Settings corresponding to TLS level based on Mozilla’s server side TLS recommendations. See its documentation for more details on specifics.
Variants
MozillaModern
Settings corresponding to modern configuration of version 4 of Mozilla’s server side TLS recommendations
MozillaModernV5
Settings corresponding to modern configuration of version 5 of Mozilla’s server side TLS recommendations
MozillaIntermediate
Settings corresponding to the intermediate configuration of version 4 of Mozilla’s server side TLS recommendations
MozillaIntermediateV5
Settings corresponding to the intermediate configuration of version 5 of Mozilla’s server side TLS recommendations